==> xpi-firebug-1.8.4%2C3.tbz: lib/xpi/firebug@software.joehewitt.com/defaults/preferences/tracingConsole.js <==
// Tracing Options
pref("extensions.firebug.DBG_FBS_JSDCONTEXT", false);   // firebug trace scriptinfo(huge)
pref("extensions.firebug.DBG_FBS_FF_START", false);     // firebug trace from FF start(huge)
pref("extensions.firebug.DBG_FBS_CREATION", false);     // firebug script creation
pref("extensions.firebug.DBG_FBS_BP", false);           // firebug breakpoints
pref("extensions.firebug.DBG_FBS_SRCUNITS", false);     // firebug script creation
pref("extensions.firebug.DBG_FBS_ERRORS", false);       // firebug errors
pref("extensions.firebug.DBG_FBS_FINDDEBUGGER", false); // firebug findDebugger
pref("extensions.firebug.DBG_FBS_STEP", false);         // firebug stepping
pref("extensions.firebug.DBG_FBS_TRACKFILES", false);   // dump all js files to disk
pref("extensions.firebug.DBG_FBS_FUNCTION", false);     // firebug new Function
pref("extensions.firebug.DBG_ACTIVATION", false);       // firebug.js and tabWatcher.js
pref("extensions.firebug.DBG_BP", false);               // debugger.js and firebug-services.js; lots of output
pref("extensions.firebug.DBG_COMPILATION_UNITS", false);// debugger.js and firebug-services.js; lots of output
pref("extensions.firebug.DBG_TOPLEVEL", false);         // top level jsd scripts
pref("extensions.firebug.DBG_STACK", false);            // call stack, mostly debugger.js
pref("extensions.firebug.DBG_UI_LOOP", false);          // debugger.js
pref("extensions.firebug.DBG_ERRORS", false);           // error.js
pref("extensions.firebug.DBG_ERRORLOG", false);         // error.js
pref("extensions.firebug.DBG_FUNCTION_NAMES", false);   // heuristics for anon functions
pref("extensions.firebug.DBG_EVAL", false);             // debugger.js and firebug-service.js
pref("extensions.firebug.DBG_EVENTS", false);           // browser generated events
pref("extensions.firebug.DBG_PANELS", false);           // panel selection
pref("extensions.firebug.DBG_CACHE", false);            // sourceCache
pref("extensions.firebug.DBG_CONSOLE", false);          // console
pref("extensions.firebug.DBG_COMMANDLINE", false);      // command line
pref("extensions.firebug.DBG_CSS", false);              //
pref("extensions.firebug.DBG_CSS_PARSER", false);       //
pref("extensions.firebug.DBG_DBG2FIREBUG", false);      //
pref("extensions.firebug.DBG_DOM", false);              //
pref("extensions.firebug.DBG_DOMPLATE", false);         // domplate engine
pref("extensions.firebug.DBG_DISPATCH", false);         //
pref("extensions.firebug.DBG_HTML", false);             //
pref("extensions.firebug.DBG_LINETABLE", false);        //
pref("extensions.firebug.DBG_LOCATIONS", false);        // panelFileList
pref("extensions.firebug.DBG_MEMORY_PROFILER", false);  //
pref("extensions.firebug.DBG_SOURCEFILES", false);      // debugger and sourceCache
pref("extensions.firebug.DBG_WINDOWS", false);          // tabWatcher, dispatch events; very useful for understand modules/panels
pref("extensions.firebug.DBG_NET", false);              // net.js
pref("extensions.firebug.DBG_NET_EVENTS", false);       // net.js - network events
pref("extensions.firebug.DBG_INITIALIZE", false);       // initialize FB
pref("extensions.firebug.DBG_REGISTRATION", false);     // registry (modules panels);
pref("extensions.firebug.DBG_INSPECT", false);          // inspector
pref("extensions.firebug.DBG_OPTIONS", false);          //
pref("extensions.firebug.DBG_FBS_FLUSH", false);        //
pref("extensions.firebug.DBG_HTTPOBSERVER", false);     // Centralized HTTP Observer
pref("extensions.firebug.DBG_SPY", false);              // spy.js
pref("extensions.firebug.DBG_JSONVIEWER", false);       // json explorer
pref("extensions.firebug.DBG_EDITOR", false);           // Inline editors
pref("extensions.firebug.DBG_SHORTCUTS", false);        // Keyboard shortcuts
pref("extensions.firebug.DBG_A11Y", false);             // a11y
pref("extensions.firebug.DBG_LOCALE", false);           // localization, missing strings
pref("extensions.firebug.DBG_INFOTIP", false);          // popup info tip in panels
pref("extensions.firebug.DBG_ANNOTATIONS", false);      // Page annotations service
pref("extensions.firebug.DBG_XMLVIEWER", false);        // xml explorer
pref("extensions.firebug.DBG_SVGVIEWER", false);        // svg explorer
pref("extensions.firebug.DBG_ACTIVITYOBSERVER", false); // Net panel's activity observer
pref("extensions.firebug.DBG_TOOLTIP", false);          // tooltip debugging
pref("extensions.firebug.DBG_HISTORY", false);          // panel navigation history
pref("extensions.firebug.DBG_STORAGE", false);          // storageService
pref("extensions.firebug.DBG_MODULES", false);          // moduleloading
pref("extensions.firebug.DBG_PROFILER", false);         // profiler
pref("extensions.firebug.DBG_SEARCH", false);           // search box
pref("extensions.firebug.DBG_EXTERNALEDITORS", false);  // integration with external editors/IDEs
pref("extensions.firebug.DBG_OBSERVERS", false);        // track/untrack support, should be set, then restart Firefox

==> xpi-firebug-1.9.2%2C3.tbz: lib/xpi/firebug@software.joehewitt.com/defaults/preferences/tracingConsole.js <==
// Tracing Options
pref("extensions.firebug.DBG_FBS_JSDCONTEXT", false);   // firebug trace scriptinfo(huge)
pref("extensions.firebug.DBG_FBS_FF_START", false);     // firebug trace from FF start(huge)
pref("extensions.firebug.DBG_FBS_CREATION", false);     // firebug script creation
pref("extensions.firebug.DBG_FBS_BP", false);           // firebug breakpoints
pref("extensions.firebug.DBG_FBS_SRCUNITS", false);     // firebug script creation
pref("extensions.firebug.DBG_FBS_ERRORS", false);       // firebug errors
pref("extensions.firebug.DBG_FBS_FINDDEBUGGER", false); // firebug findDebugger
pref("extensions.firebug.DBG_FBS_STEP", false);         // firebug stepping
pref("extensions.firebug.DBG_FBS_TRACKFILES", false);   // dump all js files to disk
pref("extensions.firebug.DBG_FBS_FUNCTION", false);     // firebug new Function
pref("extensions.firebug.DBG_ACTIVATION", false);       // firebug.js and tabWatcher.js
pref("extensions.firebug.DBG_BP", false);               // debugger.js and firebug-services.js; lots of output
pref("extensions.firebug.DBG_COMPILATION_UNITS", false);// debugger.js and firebug-services.js; lots of output
pref("extensions.firebug.DBG_TOPLEVEL", false);         // top level jsd scripts
pref("extensions.firebug.DBG_STACK", false);            // call stack, mostly debugger.js
pref("extensions.firebug.DBG_WATCH", false);            // Watch expressions
pref("extensions.firebug.DBG_UI_LOOP", false);          // debugger.js
pref("extensions.firebug.DBG_ERRORS", false);           // error.js
pref("extensions.firebug.DBG_ERRORLOG", false);         // error.js
pref("extensions.firebug.DBG_FUNCTION_NAMES", false);   // heuristics for anon functions
pref("extensions.firebug.DBG_EVAL", false);             // debugger.js and firebug-service.js
pref("extensions.firebug.DBG_EVENTS", false);           // browser generated events
pref("extensions.firebug.DBG_PANELS", false);           // panel selection
pref("extensions.firebug.DBG_CACHE", false);            // sourceCache
pref("extensions.firebug.DBG_CONSOLE", false);          // console
pref("extensions.firebug.DBG_COMMANDLINE", false);      // command line
pref("extensions.firebug.DBG_CSS", false);              //
pref("extensions.firebug.DBG_CSS_PARSER", false);       //
pref("extensions.firebug.DBG_DBG2FIREBUG", false);      //
pref("extensions.firebug.DBG_DOM", false);              //
pref("extensions.firebug.DBG_DOMPLATE", false);         // domplate engine
pref("extensions.firebug.DBG_DISPATCH", false);         //
pref("extensions.firebug.DBG_HTML", false);             //
pref("extensions.firebug.DBG_LINETABLE", false);        //
pref("extensions.firebug.DBG_LOCATIONS", false);        // panelFileList
pref("extensions.firebug.DBG_MEMORY_PROFILER", false);  //
pref("extensions.firebug.DBG_SOURCEFILES", false);      // debugger and sourceCache
pref("extensions.firebug.DBG_WINDOWS", false);          // tabWatcher, dispatch events; very useful for understand modules/panels
pref("extensions.firebug.DBG_NET", false);              // net.js
pref("extensions.firebug.DBG_NET_EVENTS", false);       // net.js - network events
pref("extensions.firebug.DBG_INITIALIZE", false);       // initialize FB
pref("extensions.firebug.DBG_REGISTRATION", false);     // registry (modules panels);
pref("extensions.firebug.DBG_INSPECT", false);          // inspector
pref("extensions.firebug.DBG_OPTIONS", false);          //
pref("extensions.firebug.DBG_FBS_FLUSH", false);        //
pref("extensions.firebug.DBG_HTTPOBSERVER", false);     // Centralized HTTP Observer
pref("extensions.firebug.DBG_SPY", false);              // spy.js
pref("extensions.firebug.DBG_EDITOR", false);           // Inline editors
pref("extensions.firebug.DBG_SHORTCUTS", false);        // Keyboard shortcuts
pref("extensions.firebug.DBG_A11Y", false);             // a11y
pref("extensions.firebug.DBG_LOCALE", false);           // localization, missing strings
pref("extensions.firebug.DBG_INFOTIP", false);          // popup info tip in panels
pref("extensions.firebug.DBG_ANNOTATIONS", false);      // Page annotations service
pref("extensions.firebug.DBG_XMLVIEWER", false);        // XML explorer
pref("extensions.firebug.DBG_JSONVIEWER", false);       // JSON explorer
pref("extensions.firebug.DBG_SVGVIEWER", false);        // SVG explorer
pref("extensions.firebug.DBG_FONTS", false);            // Fonts information and font viewer
pref("extensions.firebug.DBG_ACTIVITYOBSERVER", false); // Net panel's activity observer
pref("extensions.firebug.DBG_TOOLTIP", false);          // tooltip debugging
pref("extensions.firebug.DBG_HISTORY", false);          // panel navigation history
pref("extensions.firebug.DBG_STORAGE", false);          // storageService
pref("extensions.firebug.DBG_MODULES", false);          // moduleloading
pref("extensions.firebug.DBG_PROFILER", false);         // profiler
pref("extensions.firebug.DBG_SEARCH", false);           // search box
pref("extensions.firebug.DBG_EXTERNALEDITORS", false);  // integration with external editors/IDEs
pref("extensions.firebug.DBG_OBSERVERS", false);        // track/untrack support, should be set, then restart Firefox
pref("extensions.firebug.DBG_EVENTLISTENERS", false);   // track/untrack for registered event listeners, restart needed
